# PySpark
- > [Microsoft](https://learn.microsoft.com/en-us/training/modules/use-apache-spark-work-files-lakehouse/2-spark): a Spark-specific variant of Python
- > Python API for Apache Spark


# [Structured Streaming](https://spark.apache.org/docs/latest/api/python/index.html#index-page-structured-streaming) 
